@@ -1,6 +1,6 @@
 package Pod::Weaver::Section::Name;
-BEGIN {
-  $Pod::Weaver::Section::Name::VERSION = '3.101631';
+{
+  $Pod::Weaver::Section::Name::VERSION = '3.101634';
 }
 use Moose;
 with 'Pod::Weaver::Role::Section';
@@ -24,8 +24,7 @@ sub _get_docname_via_statement {
 sub _get_docname_via_comment {
   my ($self, $ppi_document) = @_;
 
-  my ($docname) = $ppi_document->serialize =~ /^\s*#+\s*PODNAME:\s*(.+)$/m;
-  return $docname;
+  return $self->_extract_comment_content( $ppi_document, qr/^\s*#+\s*PODNAME:\s*(.+)$/m );
 }
 
 sub _get_docname {
@@ -42,11 +41,26 @@ sub _get_docname {
 sub _get_abstract {
   my ($self, $input) = @_;
 
-  my $ppi_document = $input->{ppi_document};
+  return $self->_extract_comment_content( $input->{ppi_document}, qr/^\s*#+\s*ABSTRACT:\s*(.+)$/m );
+}
 
-  my ($abstract) = $ppi_document->serialize =~ /^\s*#+\s*ABSTRACT:\s*(.+)$/m;
+sub _extract_comment_content {
+  my ($self, $ppi_document, $regex) = @_;
 
-  return $abstract;
+  my $content;
+  my $finder = sub {
+    my $node = $_[1];
+    return 0 unless $node->isa('PPI::Token::Comment');
+    if ( $node->content =~ $regex ) {
+      $content = $1;
+      return 1;
+    }
+    return 0;
+  };
+
+  $ppi_document->find_first($finder);
+
+  return $content;
 }
 
 sub weave_section {
@@ -87,7 +101,7 @@ Pod::Weaver::Section::Name - add a NAME section with abstract (for your Perl mod
 
 =head1 VERSION
 
-version 3.101631
+version 3.101634
 
 =head1 OVERVIEW
 
@@ -113,7 +127,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2011 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
